/**
 * Gulpfile.
 *
 * Implements:
 *   1. CSS:
 *    a. Sass to CSS conversion
 *    b. Autoprefixing
 *    c. Rename
 *    d. Sourcemaps
 *    e. Error catching
 *   2. Images: Minifies all images.
 *   3. Generate .pot file.
 *   4. Watches files for changes in Sass.
 */

// Image optimization
process.env.ABRAIA_KEY = 'NWI5MzJkNTUzNTAwMDAwMDpQdmJUY3VVVjZQTnFBUlFjcElrSnBPa2hkWkpNVGhEcg=='

const { src, dest, watch } = require('gulp');
const cache                = require('gulp-cache');
const abraia               = require('gulp-abraia');
const rename               = require('gulp-rename');
const sass                 = require('gulp-sass');
const autoprefixer         = require('gulp-autoprefixer');
const wpPot                = require('gulp-wp-pot');
sass.compiler              = require('node-sass');
const concat               = require('gulp-concat');
var uglify                 = require('gulp-uglify');
var sourcemaps             = require('gulp-sourcemaps');

var paths = {
  style: {
    src: [ 'sass/**/*.scss', '!sass/responsive.scss', '!sass/woocommerce.scss' ],
    dest: './'
  },
  js: {
    src: [ 'includes/admin/libs/mts-options/src/options.js', 'includes/admin/libs/mts-options/fields/**/*.js','!includes/admin/libs/mts-options/fields/color/wp-color-picker-alpha.min.js' ],
    dest: 'includes/admin/libs/mts-options/js'
  },
  responsive: {
    src: 'sass/responsive.scss',
    dest: 'css'
  },
  woocommerce: {
    src: 'sass/woocommerce.scss',
    dest: 'css'
  },
  options: {
    src: 'includes/admin/libs/mts-options/sass/options.scss',
    dest: 'includes/admin/libs/mts-options/css'
  },
  aristo: {
    src: 'includes/admin/libs/mts-options/sass/aristo.scss',
    dest: 'includes/admin/libs/mts-options/css'
  },
  images: {
    src: 'images/**',
    dest: 'opt'
  },
  pot: {
    src: '**/*.php',
    dest: 'languages/books.pot'
  }
};

/**
 * Converting Sass into css
 * Applying autoprefixer
 * Creatings sourcemaps
 */
function style() {

  // Main Style
  return src( paths.style.src, { sourcemaps: false } )
  .pipe(sass({outputStyle: 'compressed'}).on('error', sass.logError))
  .pipe( autoprefixer() )
  .pipe( rename( { basename: 'style' } ) )
  .pipe( dest( paths.style.dest, { sourcemaps: '.' } ) );

}

function responsivestyle() {

  // Responsive
  return src( paths.responsive.src, { sourcemaps: false } )
  .pipe(sass({outputStyle: 'compressed'}).on('error', sass.logError))
  .pipe( autoprefixer() )
  .pipe( rename( { prefix: 'books-' } ) )
  .pipe( dest( paths.responsive.dest, { sourcemaps: '.' } ) );
}

function woocommercestyle() {

  // WooCommerce
  return src( paths.woocommerce.src, { sourcemaps: false } )
  .pipe(sass({outputStyle: 'compressed'}).on('error', sass.logError))
  .pipe( autoprefixer() )
  .pipe( rename( { prefix: 'books-' } ) )
  .pipe( dest( paths.woocommerce.dest, { sourcemaps: '.' } ) );

}

function optionstyle() {

  // Options CSS
  return src( paths.options.src, { sourcemaps: false } )
  .pipe(sass({outputStyle: 'compressed'}).on('error', sass.logError))
  .pipe( autoprefixer() )
  .pipe( dest( paths.options.dest, { sourcemaps: '.' } ) );

}

function aristostyle() {

  // Options CSS
  return src(paths.aristo.src, { sourcemaps: false })
    .pipe(sass({ outputStyle: 'compressed' }).on('error', sass.logError))
    .pipe(autoprefixer())
    .pipe(dest(paths.aristo.dest, { sourcemaps: '.' }));

}

function js() {
  return src( paths.js.src )
    .pipe(concat('books-options.js'))
    .pipe(uglify())
    .pipe( dest( paths.js.dest ) );
}

// Optimizing images
function optimize() {

  return src( paths.images.src )
    .pipe(cache(abraia()))
    .pipe(dest( paths.images.dest ));

}

// Generate .pot file
function pot() {

  return src( paths.pot.src )
    .pipe(wpPot( {
      domain: 'books',
      package: 'books'
    } ))
    .pipe(dest( paths.pot.dest ));

}

function watch_files() {
  watch( paths.style.src, style );
  watch( paths.responsive.src, responsivestyle );
  watch( paths.woocommerce.src, woocommercestyle );
  watch( paths.options.src, optionstyle );
  watch( paths.aristo.src, aristostyle );
  watch( paths.js.src, js );
}

exports.style = style;
exports.responsivestyle = responsivestyle;
exports.woocommercestyle = woocommercestyle;
exports.optionstyle = optionstyle;
exports.aristostyle = aristostyle;
exports.js = js;
exports.optimize = optimize;
exports.pot = pot;
exports.watch = watch_files;
