<?php
/**
 * Set books layout according to options
 *
 * @package Books
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Books_Layout extends Books_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'books_before_wrapper', 'add_header' );
		$this->add_action( 'books_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'books_before_footer', 'full_related_posts' );
		$this->add_action( 'books_before_content', 'add_breadcrumb' );
	}


	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = array(
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		);
		$layout = books_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Add Breadcrumb section
	 */
	public function add_breadcrumb() {

		if ( is_home() || ! books_get_settings( 'show_breadcrumb' ) ) {
			return;
		}

		echo '<div class="container">';
		books_breadcrumbs();
		echo '</div>';
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {

		if ( ! has_post_thumbnail() ) {
			return;
		}

		if ( ! books_get_post_header_effect() && books_get_settings( 'show_single_featured' ) ) {
			$attr = [
				'class'   => 'single-featured-image',
				'title'   => esc_attr( get_the_title() ),
				'alt'     => esc_attr( get_the_title() ),
				'loading' => 'lazy',
			];
			echo '<div class="single-featured-wrap">';
			the_post_thumbnail( 'books-featured', $attr );
			echo '</div>';
		}

	}

	/**
	 * Single post related posts
	 */
	public function full_related_posts() {

		if ( 'full' !== books_get_settings( 'related_posts_position' ) ) {
			return;
		}
		books_related_posts();

	}

}

// Init.
new Books_Layout();
