<?php
/**
 * Single Sections
 *
 * @package Books
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Books_Single_Sections extends Books_Base {

	/**
	 * Render function
	 */
	public function render() {
		$single_layout = books_get_settings( 'mts_single_post_layout' );
		?>
		<article class="<?php books_article_class(); ?>">
			<?php
			if ( 'mts_nosidebar' !== mts_custom_sidebar() ) {
				$sidebar = books_custom_sidebar_layout();
			} else {
				$sidebar = 'nosidebar';
			}
			?>
			<div id="content_box" class="<?php echo $sidebar; ?>">
				<?php
				// Elementor 'single' location.
				if ( ! books_is_elementor( 'single' ) ) {
					if ( have_posts() ) :
						while ( have_posts() ) :
							the_post();
							?>
							<div id="post-<?php the_ID(); ?>" <?php post_class( 'g post' ); ?>>
								<?php
								// Single post parts ordering.
								if ( ( null !== $single_layout ) && is_array( $single_layout ) && array_key_exists( 'enabled', $single_layout ) ) {
									$single_post_parts = $single_layout['enabled'];
								} else {
									$single_post_parts = [
										'content'   => 'content',
										'author'    => 'author',
										'related'   => 'related',
										'subscribe' => 'subscribe',
									];
								}

								foreach ( $single_post_parts as $part => $label ) {
									switch ( $part ) {
										// Content area.
										case 'content':
											books()->single_sections->single_post();
											break;

										// Author box.
										case 'author':
											books()->single_sections->single_author_section();
											break;

										// Related Posts.
										case 'related':
											if ( 'default' === books_get_settings( 'related_posts_position' ) ) {
												books_related_posts();
											}
											break;

										// Subscribe box.
										case 'subscribe':
											books()->single_sections->single_subscribe_box();
											break;
									}
								}
								?>
							</div><!--.g post-->
							<?php
							// Comment area.
							comments_template( '', true );

						endwhile;
						wp_reset_postdata();
					endif; /* end loop */
				}
				?>
			</div>
		</article>
		<?php
	}

	/**
	 * Single post structure
	 */
	public function single_post() {
		?>
		<div class="single_post">

			<?php
			books_action( 'single_post_header_thumb' );

			$this->single_post_header();
			?>

			<div class="post-single-content box mark-links entry-content">

				<?php
				$this->single_post_ads( 'above' );

				$this->single_post_content();

				$this->single_post_pagination();

				$this->single_tag_section();

				$this->single_post_ads( 'below' );

				$this->single_post_social_icons( 'below' );
				?>

			</div><!--.post-single-content-->

		</div><!--.single_post-->
		<?php
	}

	/**
	 * Single post header
	 */
	public function single_post_header() {
		?>
		<header class="single-full-header clearfix">

			<?php $this->single_post_social_icons( 'above' ); ?>

			<div class="single-postinfo-wrapper">
				<?php books_the_post_meta( 'single' ); ?>
			</div>

			<h1 class="title single-title entry-title"><?php the_title(); ?></h1>

		</header><!--.single-full-header-->
		<?php
	}

	/**
	 * Single content
	 */
	public function single_post_content() {
		echo '<div class="thecontent">';
			the_content();
		echo '</div>';
	}

	/**
	 * Single post pagination
	 */
	public function single_post_pagination() {
		// Single Post Pagination.
		$args = [
			'before'           => '<div class="pagination">',
			'after'            => '</div>',
			'link_before'      => '<span class="current"><span class="currenttext">',
			'link_after'       => '</span></span>',
			'next_or_number'   => 'next_and_number',
			'nextpagelink'     => '<i class="fa fa-angle-right"></i>',
			'previouspagelink' => '<i class="fa fa-angle-left"></i>',
			'pagelink'         => '%',
			'echo'             => 1,
		];
		wp_link_pages( $args );
	}

	/**
	 * Single tag section
	 */
	public function single_tag_section() {

		if ( ! books_get_settings( 'show_single_tags' ) ) {
			return;
		}

		books_post_tags( '<div class="tags">', '' );
	}


	/**
	 * Single Author section
	 */
	public function single_author_section() {
		?>
			<div class="postauthor">

				<?php
				// Author box title.
				$author_title = books_get_settings( 'author_box_title' );
				if ( $author_title ) {
					echo '<h4>' . $author_title . '</h4>';
				}
				// Author gravatar.
				if ( books_get_settings( 'author_box_image' ) && function_exists( 'get_avatar' ) ) {
					echo get_avatar( get_the_author_meta( 'email' ), '102' ); // Gravatar size.
				}
				?>
				<h5 class="vcard author">
					<?php echo '<span>' . esc_html__( 'Post by ', 'books' ) . '</span>'; ?>
					<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" class="fn">
						<?php the_author_meta( 'display_name' ); ?>
					</a>
				</h5>
				<p><?php the_author_meta( 'description' ); ?></p>
			</div>
		<?php
	}

	/**
	 * Single Subscribe box
	 */
	public function single_subscribe_box() {
		if ( is_active_sidebar( 'single-subscribe' ) ) {
			?>
				<div class="single-subscribe clear">
					<?php dynamic_sidebar( 'single-subscribe' ); ?>
				</div>
			<?php
		}
	}

	/**
	 * Single Ads
	 *
	 * @param string $location ad location above|below.
	 */
	public function single_post_ads( $location ) {
		// Above Content Ad Code.
		if ( ! empty( books_get_settings( 'mts_posttop_adcode' ) ) && 'above' == $location ) {
			$toptime = ! empty( books_get_settings( 'mts_posttop_adcode_time' ) ) ? books_get_settings( 'mts_posttop_adcode_time' ) : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$toptime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="topad">
					<?php echo do_shortcode( books_get_settings( 'mts_posttop_adcode' ) ); ?>
				</div>
				<?php
			}
		}
		// Below Content Ad Code.
		if ( ! empty( books_get_settings( 'mts_postend_adcode' ) ) && 'below' == $location ) {
			$endtime = ! empty( books_get_settings( 'mts_postend_adcode_time' ) ) ? books_get_settings( 'mts_postend_adcode_time' ) : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$endtime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="bottomad">
					<?php echo do_shortcode( books_get_settings( 'mts_postend_adcode' ) ); ?>
				</div>
				<?php
			}
		}
	}

	/**
	 * Single Social icons
	 *
	 * @param string $location social icons location above|below|floating.
	 */
	public function single_post_social_icons( $location ) {

		$position = books_get_settings( 'mts_social_button_position' );

		// Social Share icons above content.
		if ( $position && ( 'top' === $position || 'both' === $position ) && 'above' == $location ) {
			echo '<div class="share-wrap top">';
				echo '<span class="share-text">' . esc_html__( 'Share this', 'books' ) . '</span>';
				books_social_buttons( 'top' );
			echo '</div>';
		}
		// Social Share icons below content.
		if ( $position && ( 'bottom' === $position || 'both' === $position ) && 'below' == $location ) {
			echo '<div class="share-wrap bottom">';
				echo '<span class="share-text">' . esc_html__( 'Share this', 'books' ) . '</span>';
				books_social_buttons( 'bottom' );
			echo '</div>';
		}
		// Social Share icons floating.
		if ( $position && 'floating' === $position && 'above' !== $location ) {
			books_social_buttons();
		}
	}

}
