<?php
/**
 * Ad Management Tab
 *
 * @package Books
 */

$menus['ad-management'] = [
	'icon'  => 'fa-bar-chart-o',
	'title' => esc_html__( 'Ad Management', 'books' ),
	'desc'  => esc_html__( 'Now, ad management is easy with our options panel. You can control everything from here, without using separate plugins.', 'books' ),
];

$sections['ad-management'] = [

	[
		'id'       => 'detect_adblocker',
		'type'     => 'switch',
		'title'    => esc_html__( 'Detect Ad Blocker', 'books' ),
		'sub_desc' => esc_html__( 'If user is using any ad blocker extension then this option will hide the content and will ask user to white-list your website.', 'books' ),
		'std'      => '0',
	],

	[
		'id'         => 'detect_adblocker_type',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Ad Blocker Notice Type', 'books' ),
		'class'      => 'green',
		'options'    => [
			'hide-content' => esc_html__( 'Hide Content', 'books' ),
			'popup'        => esc_html__( 'Show Popup', 'books' ),
			'floating'     => esc_html__( 'Floating Notice', 'books' ),
			'shortcode'    => esc_html__( 'Shortcode', 'books' ),
		],
		// translators: Ad Blocker title description.
		'sub_desc'   => sprintf( __( 'Choose Ad Blocker Notice type from here. SHORTCODE: %s ', 'books' ), '<code>[detect_adblocker title="Your Title" description="Description"]Content[/detect_adblocker]</code>' ),
		'std'        => 'popup',
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'detect_adblocker',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],
	[
		'id'         => 'detect_adblocker_title',
		'type'       => 'text',
		'title'      => esc_html__( 'Ad Blocker Title', 'books' ),
		'sub_desc'   => esc_html__( 'Enter Ad Blocker detector Title here.', 'books' ),
		'std'        => esc_html__( 'Ad Blocker Detected', 'books' ),
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'detect_adblocker',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],
	[
		'id'         => 'detect_adblocker_description',
		'type'       => 'textarea',
		'title'      => esc_html__( 'Ad Blocker Description', 'books' ),
		'sub_desc'   => esc_html__( 'Enter Ad Blocker detector Description here.', 'books' ),
		'std'        => esc_html__( 'Our website is made possible by displaying online advertisements to our visitors. Please consider supporting us by disabling your ad blocker.', 'books' ),
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'detect_adblocker',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],
	[
		'id'       => 'background_clickable',
		'type'     => 'switch',
		'title'    => esc_html__( 'Site Background Clickable', 'books' ),
		'sub_desc' => esc_html__( 'This option will make your website background clickable.', 'books' ),
		'std'      => '0',
	],
	[
		'id'         => 'background_link',
		'type'       => 'text',
		'title'      => esc_html__( 'Site Background URL', 'books' ),
		'sub_desc'   => esc_html__( 'Enter URL Here', 'books' ),
		'validate'   => 'url',
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'background_clickable',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],
	[
		'id'         => 'background_link_new_tab',
		'type'       => 'switch',
		'title'      => esc_html__( 'Site Background Click - Open in new Tab', 'books' ),
		'sub_desc'   => esc_html__( 'Enable this option to open link in a new tab.', 'books' ),
		'std'        => '1',
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'background_clickable',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],

	[
		'id'       => 'mts_header_adcode',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Header Ad', 'books' ),
		'sub_desc' => esc_html__( 'Paste your AdSense, BSA or other ad code here to show ads in Header Area.', 'books' ),
	],
	[
		'id'       => 'header_adcode_show',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Header Adcode Show on', 'books' ),
		'sub_desc' => esc_html__( 'Choose where you want to show the header adcode', 'books' ),
		'options'  => [
			'all'    => esc_html__( 'All Pages', 'books' ),
			'home'   => esc_html__( 'Home Page', 'books' ),
			'blog'   => esc_html__( 'Blog Page', 'books' ),
			'single' => esc_html__( 'Single Post', 'books' ),
			'page'   => esc_html__( 'Pages', 'books' ),
			'both'   => esc_html__( 'Blog and Single Page', 'books' ),
		],
		'std'      => 'all',
	],
	[
		'id'       => 'header_ad_size',
		'type'     => 'select',
		'title'    => esc_html__( 'Header Ad Size [For AdSense Ads]', 'books' ),
		'sub_desc' => esc_html__( 'If you leave the AdSense size boxes on Auto, the theme will automatically resize the Google ads. Note: For smaller screens ads will be set on Auto mode irrespective of size defined here.', 'books' ),
		'options'  => ad_sizes(),
		'std'      => '0',
	],
	[
		'id'       => 'mts_header_adcode_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Ad Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set header ad margin from here.', 'books' ),
		'left'     => false,
		'right'    => false,
		'std'      => [
			'top'    => '0',
			'bottom' => '0',
		],
	],

	[
		'id'       => 'navigation_ad',
		'type'     => 'switch',
		'title'    => esc_html__( 'Navigation Ad', 'books' ),
		'sub_desc' => esc_html__( 'This option will let you add an Ad below Navigation menu.', 'books' ),
		'std'      => '0',
	],
	[
		'id'         => 'navigation_adcode',
		'type'       => 'ace_editor',
		'mode'       => 'html',
		'title'      => esc_html__( 'Navigation Ad Code', 'books' ),
		'sub_desc'   => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads in the Header.', 'books' ),
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'navigation_ad',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],
	[
		'id'         => 'navigation_ad_size',
		'type'       => 'select',
		'title'      => esc_html__( 'Navigation Ad Size [For AdSense Ads]', 'books' ),
		'sub_desc'   => esc_html__( 'If you leave the AdSense size boxes on Auto, the theme will automatically resize the Google ads. Note: For smaller screens ads will be set on Auto mode irrespective of size defined here.', 'books' ),
		'options'    => ad_sizes(),
		'std'        => '26',
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'navigation_ad',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],
	[
		'id'         => 'navigation_ad_background',
		'type'       => 'color',
		'title'      => esc_html__( 'Navigation Ad Background', 'books' ),
		'sub_desc'   => esc_html__( 'Set background color for navigation Ad from here.', 'books' ),
		'std'        => '#252525',
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'navigation_ad',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],

	[
		'id'       => 'mts_postfooter_adcode',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Before Footer', 'books' ),
		'sub_desc' => esc_html__( 'Paste your AdSense, BSA or other ad code here to show ads before footer.', 'books' ),
	],
	[
		'id'       => 'mts_postfooter_adcode_time',
		'type'     => 'text',
		'title'    => esc_html__( 'Show After X Days', 'books' ),
		'sub_desc' => esc_html__( 'Enter the number of days after which you want to show the before footer. Enter 0 to disable this feature.', 'books' ),
		'validate' => 'numeric',
		'std'      => '0',
		'class'    => 'small-text',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'       => 'mts_posttop_adcode',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Below Post Title', 'books' ),
		'sub_desc' => esc_html__( 'Paste your AdSense, BSA or other ad code here to show ads below your article title on single posts.', 'books' ),
	],
	[
		'id'       => 'mts_posttop_adcode_time',
		'type'     => 'text',
		'title'    => esc_html__( 'Show After X Days', 'books' ),
		'sub_desc' => esc_html__( 'Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'books' ),
		'validate' => 'numeric',
		'std'      => '0',
		'class'    => 'small-text',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'       => 'mts_postend_adcode',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Below Post Content', 'books' ),
		'sub_desc' => esc_html__( 'Paste your AdSense, BSA or other ad code here to show ads below the post content on single posts.', 'books' ),
	],
	[
		'id'       => 'mts_postend_adcode_time',
		'type'     => 'text',
		'title'    => esc_html__( 'Show After X Days', 'books' ),
		'sub_desc' => esc_html__( 'Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'books' ),
		'validate' => 'numeric',
		'std'      => '0',
		'class'    => 'small-text',
		'args'     => [ 'type' => 'number' ],
	],
];
