<?php
/**
 * HomePage Pagination
 *
 * @package Books
 */

$menus['blog-pagination'] = [
	'icon'  => 'fa-ellipsis-h',
	'title' => esc_html__( 'Pagination', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the elements of pagination.', 'books' ),
];

// Dependency check - Default and Numbered pagination.
$default_pagination_dependency = [
	'relation' => 'and',
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '!=',
	],
];

// Dependency check the load more button.
$loadmore_button_dependency = [
	'relation' => 'and',
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '==',
	],
];

$sections['blog-pagination'] = [

	[
		'id'       => 'mts_pagenavigation_type',
		'type'     => 'radio',
		'title'    => esc_html__( 'Pagination Type', 'books' ),
		'sub_desc' => esc_html__( 'Select pagination type.', 'books' ),
		'options'  => [
			'0' => esc_html__( 'Default (Next / Previous)', 'books' ),
			'1' => esc_html__( 'Numbered (1 2 3 4...)', 'books' ),
			'2' => esc_html__( 'AJAX (Load More Button)', 'books' ),
			'3' => esc_html__( 'AJAX (Auto Infinite Scroll)', 'books' ),
		],
		'std'      => '1',
	],

	[
		'id'         => 'pagenavigation_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Pagination Alignment', 'books' ),
		'sub_desc'   => esc_html__( 'Choose pagination alignment from here.', 'books' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'books' ),
			'center' => esc_html__( 'Center', 'books' ),
			'right'  => esc_html__( 'Right', 'books' ),
		],
		'std'        => 'center',
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'load_more_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Load More Alignment', 'books' ),
		'sub_desc'   => esc_html__( 'Choose the load more alignment from here.', 'books' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'books' ),
			'center' => esc_html__( 'Center', 'books' ),
			'right'  => esc_html__( 'Right', 'books' ),
			'full'   => esc_html__( 'Full Width', 'books' ),
		],
		'std'        => 'center',
		'dependency' => $loadmore_button_dependency,
	],

	[
		'id'         => 'mts_pagenavigation_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Pagination background color', 'books' ),
		'sub_desc'   => esc_html__( 'Select pagination background color.', 'books' ),
		'options'    => [
			'color'         => false,            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'gradient',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#ffffff',
				'direction' => '0deg',
			],
		],
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'load_more_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Load More background color', 'books' ),
		'sub_desc'   => esc_html__( 'Select background color for load more button.', 'books' ),
		'options'    => [
			'color'         => false,            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'gradient',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#ffffff',
				'direction' => '0deg',
			],
		],
		'dependency' => $loadmore_button_dependency,
	],

	[
		'id'         => 'mts_pagenavigation_hover_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Pagination background hover color', 'books' ),
		'sub_desc'   => esc_html__( 'Select pagination background hover color.', 'books' ),
		'options'    => [
			'color'         => false,            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'gradient',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#81d1d4',
				'to'        => '#81d1d4',
				'direction' => '0deg',
			],
		],
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'mts_pagenavigation_active_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Pagination background Active color', 'books' ),
		'sub_desc'   => esc_html__( 'Select pagination background active color.', 'books' ),
		'options'    => [
			'color'         => false,            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'gradient',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#914bbe',
				'to'        => '#ce5ca7',
				'direction' => '135deg',
			],
		],
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'load_more_hover_bgcolor',
		'type'       => 'background',
		'title'      => esc_html__( 'Load More background hover color', 'books' ),
		'sub_desc'   => esc_html__( 'Select load more background hover color.', 'books' ),
		'options'    => [
			'color'         => false,            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => false,            // false to disable, not needed otherwise.
			'repeat'        => false,       // false to disable, array of options to override default ( optional ).
			'attachment'    => false,       // false to disable, array of options to override default ( optional ).
			'position'      => false,       // false to disable, array of options to override default ( optional ).
			'size'          => false,       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => false,       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'use'           => 'gradient',
			'image_pattern' => 'nobg',
			'gradient'      => [
				'from'      => '#81d1d4',
				'to'        => '#81d1d4',
				'direction' => '0deg',
			],
		],
		'dependency' => $loadmore_button_dependency,
	],

	[
		'id'         => 'mts_pagenavigation_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination color', 'books' ),
		'sub_desc'   => esc_html__( 'Select pagination color.', 'books' ),
		'std'        => '#383567',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More color', 'books' ),
		'sub_desc'   => esc_html__( 'Select color for load more button.', 'books' ),
		'std'        => '#484055',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination hover color', 'books' ),
		'sub_desc'   => esc_html__( 'Select pagination hover color.', 'books' ),
		'std'        => '#ffffff',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More hover color', 'books' ),
		'sub_desc'   => esc_html__( 'Select hover color for load more button.', 'books' ),
		'std'        => '#ffffff',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'       => 'mts_pagenavigation_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Pagination Margin', 'books' ),
		'sub_desc' => esc_html__( 'Update pagination margin from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => books_px2rem( '16px' ),
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'         => 'mts_pagenavigation_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Pagination Padding', 'books' ),
		'sub_desc'   => esc_html__( 'Update pagination padding from here.', 'books' ),
		'std'        => [
			'top'    => '18px',
			'right'  => '21px',
			'bottom' => '17px',
			'left'   => '21px',
		],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Load More Padding', 'books' ),
		'sub_desc'   => esc_html__( 'Update padding for load more button from here.', 'books' ),
		'std'        => [
			'top'    => books_px2rem( '25px' ),
			'right'  => books_px2rem( '30px' ),
			'bottom' => books_px2rem( '25px' ),
			'left'   => books_px2rem( '30px' ),
		],
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'       => 'mts_pagenavigation_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Pagination border radius', 'books' ),
		'sub_desc' => esc_html__( 'Update pagination border radius in px.', 'books' ),
		'std'      => '5',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'       => 'pagenavigation_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'books' ),
		'sub_desc' => esc_html__( 'Select border', 'books' ),
	],
	[
		'id'    => 'pagination_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Pagination', 'books' ),
		'color' => false,
		'std'   => [
			'preview-text'  => 'Pagination',
			'preview-color' => 'light',
			'font-family'   => 'Montserrat',
			'font-weight'   => '700',
			'font-size'     => '13px',
			'css-selectors' => '.pagination, #load-posts a',
		],
	],

];
