<?php
/**
 * HomePage Posts
 *
 * @package Books
 */

$features = books_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = $feature['mts_featured_title'] ? $feature['mts_featured_title'] : 'New Section';
	$posts_layout = $feature['blog_layout'] ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = [
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'books' ) ), $title ),
	];

	// Dependency check that back to top option is enable.
	$post_title_dependency = [
		'relation' => 'and',
		[
			'field'      => 'featured_category_title_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		],
	];

	$sections[ 'blog-' . $unique_id ] = [

		/**
		 * Layout Default Settings
		 *
		 * @package Books
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'books' ),
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'books' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'books' ),
			'std'      => '0',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'books' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'books' ),
			'options'    => [
				'left'   => esc_html__( 'Left', 'books' ),
				'center' => esc_html__( 'Center', 'books' ),
				'right'  => esc_html__( 'Right', 'books' ),
			],
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'books' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'books' ),
			'options'    => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'        => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'books' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'books' ),
			'std'        => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => books_px2rem( '30px' ),
				'left'   => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'books' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'books' ),
			'std'        => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'books' ),
			'sub_desc'   => esc_html__( 'Select border', 'books' ),
			'dependency' => $post_title_dependency,
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'books' ),
			'std'        => [
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'font-size'     => '24px',
				'color'         => '#484055',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			'dependency' => $post_title_dependency,
		] : null,

		// Meta info.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'books' ),
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'       => 'blog_meta_info' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'books' ),
			'sub_desc' => esc_html__( 'Show or hide post meta info.', 'books' ),
			'options'  => [
				'category' => esc_html__( 'Category', 'books' ),
				'date'     => esc_html__( 'Date', 'books' ),
				'author'   => esc_html__( 'Author Name', 'books' ),
				'comment'  => esc_html__( 'Comments', 'books' ),
				'readmore' => esc_html__( 'Read More', 'books' ),
			],
			'std'      => [
				'category',
				'date',
				'author',
				'comment',
				'readmore',
			],
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'books' ),
			'std'   => [
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '13px',
				'margin-top'     => books_px2rem( '43px' ),
				'color'          => '#a39faa',
				'letter-spacing' => '3.172px',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			],
		] : null,
		// Post Container.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'books' ),
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'books' ),
			'sub_desc' => esc_html__( 'Select border', 'books' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'books' ),
			'sub_desc' => esc_html__( 'Post margin.', 'books' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => '0',
				'bottom' => '12px',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'books' ),
			'sub_desc' => esc_html__( 'Post padding.', 'books' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'books' ),
			'std'   => [
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '36px',
				'line-height'    => '1.11',
				'margin-top'     => books_px2rem( '30px' ),
				'color'          => '#484055',
				'letter-spacing' => '-0.504px',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'books' ),
			'std'   => [
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'font-size'     => '13px',
				'line-height'   => '1.769',
				'margin-top'    => books_px2rem( '17px' ),
				'color'         => '#6d6677',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
		] : null,

		/**
		 * Layout Grid Settings
		 *
		 * @package Books
		 */

		// Section Title.
		( 'layout-grid' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'books' ),
		] : null,

		( 'layout-grid' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'books' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'books' ),
			'std'      => '0',
		] : null,
		( 'layout-grid' === $posts_layout ) ? [
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'books' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'books' ),
			'options'    => [
				'left'   => esc_html__( 'Left', 'books' ),
				'center' => esc_html__( 'Center', 'books' ),
				'right'  => esc_html__( 'Right', 'books' ),
			],
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-grid' === $posts_layout ) ? [
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'books' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'books' ),
			'options'    => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'        => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-grid' === $posts_layout ) ? [
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'books' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'books' ),
			'std'        => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => books_px2rem( '30px' ),
				'left'   => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-grid' === $posts_layout ) ? [
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'books' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'books' ),
			'std'        => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			'dependency' => $post_title_dependency,
		] : null,
		( 'layout-grid' === $posts_layout ) ? [
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'books' ),
			'sub_desc'   => esc_html__( 'Select border', 'books' ),
			'dependency' => $post_title_dependency,
		] : null,

		( 'layout-grid' === $posts_layout ) ? [
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'books' ),
			'std'        => [
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '700',
				'font-size'     => '24px',
				'color'         => '#484055',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			'dependency' => $post_title_dependency,
		] : null,

		// Meta info.
		( 'layout-grid' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'books' ),
		] : null,

		( 'layout-grid' === $posts_layout ) ? [
			'id'       => 'blog_meta_info' . $unique_id,
			'type'     => 'multi_checkbox',
			'title'    => esc_html__( 'Post Meta Info', 'books' ),
			'sub_desc' => esc_html__( 'Show or hide post meta info.', 'books' ),
			'options'  => [
				'category' => esc_html__( 'Category', 'books' ),
				'date'     => esc_html__( 'Date', 'books' ),
				'author'   => esc_html__( 'Author Name', 'books' ),
				'comment'  => esc_html__( 'Comments', 'books' ),
				'readmore' => esc_html__( 'Read More', 'books' ),
			],
			'std'      => [
				'date',
			],
		] : null,

		( 'layout-grid' === $posts_layout ) ? [
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'books' ),
			'std'   => [
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '13px',
				'color'          => '#a39faa',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 3.172px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			],
		] : null,
		// Post Container.
		( 'layout-grid' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'books' ),
		] : null,

		( 'layout-grid' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'books' ),
			'sub_desc' => esc_html__( 'Select border', 'books' ),
		] : null,
		( 'layout-grid' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'books' ),
			'sub_desc' => esc_html__( 'Post margin.', 'books' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => '0',
				'bottom' => '12px',
			],
		] : null,
		( 'layout-grid' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'books' ),
			'sub_desc' => esc_html__( 'Post padding.', 'books' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,

		( 'layout-grid' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'books' ),
			'std'   => [
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Montserrat',
				'font-weight'    => '700',
				'font-size'      => '26px',
				'line-height'    => '1.11',
				'margin-top'     => books_px2rem( '16px' ),
				'color'          => '#484055',
				'additional-css' => 'letter-spacing: -0.504px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,

		( 'layout-grid' === $posts_layout ) ? [
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'books' ),
			'std'   => [
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Montserrat',
				'font-weight'   => '500',
				'font-size'     => '13px',
				'line-height'   => '1.769',
				'margin-top'    => books_px2rem( '17px' ),
				'color'         => '#6d6677',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
		] : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Books
		 */
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'books' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'books' ),
		] : null,
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'books' ),
			'sub_desc' => esc_html__( 'Post margin.', 'books' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => '0',
				'bottom' => '0',
			],
		] : null,
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'books' ),
			'sub_desc' => esc_html__( 'Post padding.', 'books' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,

	];
endforeach;
