<?php
/**
 * HomePage Tab
 *
 * @package Books
 */

$menus['blog'] = [
	'icon'  => 'fa-list-alt',
	'title' => esc_html__( 'Blog', 'books' ),
];

$menus['blog']['child']['blog-general'] = [
	'title' => esc_html__( 'General', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the Blog page.', 'books' ),
];

$sections['blog-general'] = [

	[
		'id'                => 'featured_categories',
		'type'              => 'group',
		'title'             => esc_html__( 'Blog Sections', 'books' ),
		'sub_desc'          => esc_html__( 'Select categories appearing on the homepage.', 'books' ),
		'groupname'         => esc_html__( 'Section', 'books' ),
		'subfields'         => [
			[
				'id'    => 'mts_featured_title',
				'type'  => 'text',
				'title' => esc_html__( 'Title', 'books' ),
			],
			[
				'id'   => 'unique_id',
				'type' => 'text',
				'args' => [
					'type'  => 'hidden',
					'class' => 'hidden',
				],
			],
			[
				'id'       => 'blog_layout',
				'type'     => 'radio_img',
				'title'    => esc_html__( 'Blog Layout', 'books' ),
				'sub_desc' => wp_kses( __( 'Choose the <strong>layout</strong> for your blog posts.', 'books' ), [ 'strong' => '' ] ),
				'options'  => [
					'layout-default' => [ 'img' => $uri . 'home/layout-default.png' ],
					'layout-grid'    => [ 'img' => $uri . 'home/layout-grid.png' ],
					'layout-html'    => [ 'img' => $uri . 'home/layout-html.png' ],
				],
				'std'      => 'layout-default',
			],
			[
				'id'         => 'mts_featured_category',
				'type'       => 'select',
				'title'      => esc_html__( 'Category', 'books' ),
				'sub_desc'   => esc_html__( 'Select a category or the latest posts for this section', 'books' ),
				'std'        => 'latest',
				'data'       => 'category_slug',
				'args'       => [
					'include_latest' => 1,
					'hide_empty'     => 0,
				],
				'dependency' => [
					'relation' => 'and',
					[
						'field'      => 'blog_layout',
						'value'      => 'layout-html',
						'comparison' => '!=',
					],
				],
			],
			[
				'id'         => 'mts_featured_category_postsnum',
				'type'       => 'text',
				'class'      => 'small-text',
				'title'      => esc_html__( 'Number of posts', 'books' ),
				// translators: Description.
				'sub_desc'   => sprintf( wp_kses_post( __( 'Enter the number of posts to show in this section.<br/><strong>For Latest Posts</strong>, this setting will be ignored, and number set in <a href="%s" target="_blank">Settings&nbsp;&gt;&nbsp;Reading</a> will be used instead.', 'books' ) ), admin_url( 'options-reading.php' ) ),
				'args'       => [ 'type' => 'number' ],
				'dependency' => [
					'relation' => 'and',
					[
						'field'      => 'blog_layout',
						'value'      => 'layout-html',
						'comparison' => '!=',
					],
				],
			],

			[
				'id'         => 'mts_featured_category_excerpt',
				'type'       => 'text',
				'class'      => 'small-text',
				'title'      => esc_html__( 'Excerpt Length', 'books' ),
				'sub_desc'   => esc_html__( 'Max lenght is 55 Words.', 'books' ),
				'args'       => [ 'type' => 'number' ],
				'dependency' => [
					'relation' => 'and',
					[
						'field'      => 'blog_layout',
						'value'      => 'layout-html',
						'comparison' => '!=',
					],
				],
			],

		],
		'std'               => [
			'1' => [
				'group_title'                    => '',
				'group_sort'                     => '1',
				'mts_featured_title'             => 'Latest',
				'blog_layout'                    => 'layout-default',
				'mts_featured_category'          => 'latest',
				'mts_featured_category_postsnum' => get_option( 'posts_per_page' ),
				'mts_featured_category_excerpt'  => '36',
				'unique_id'                      => uniqid(),
			],
		],

		'validate_callback' => 'validate_featured_categories',
	],

];
