<?php
/**
 * Header Tab
 *
 * @package Books
 */

$menus['header'] = [
	'icon'  => 'fa-header',
	'title' => esc_html__( 'Header', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the elements of header section.', 'books' ),
];

$default_header_only = [
	'relation' => 'and',
	[
		'field'      => 'header_styles',
		'value'      => 'header-default',
		'comparison' => '==',
	],
];
$header_layout2_only = [
	'relation' => 'and',
	[
		'field'      => 'header_styles',
		'value'      => 'header-layout2',
		'comparison' => '==',
	],
];

$sections['header'] = [

	[
		'id'       => 'header_styles',
		'type'     => 'radio_img',
		'title'    => esc_html__( 'Header Styling', 'books' ),
		'sub_desc' => wp_kses( __( 'Choose the <strong>Header design</strong> for your site.', 'books' ), [ 'strong' => '' ] ),
		'options'  => [
			'header-default' => [ 'img' => $uri . 'headers/header-default.jpg' ],
			'header-layout2' => [ 'img' => $uri . 'headers/header-layout2.jpg' ],
		],
		'std'      => 'header-default',
	],

	[
		'id'    => 'header_general_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Header General Settings', 'books' ),
	],

	[
		'id'       => 'sticky_nav',
		'type'     => 'switch',
		'title'    => esc_html__( 'Floating Navigation Menu', 'books' ),
		// translators: Floating Navigation Menu with strong tag.
		'sub_desc' => sprintf( esc_html__( 'Use this button to enable %s.', 'books' ), '<strong>' . esc_html__( 'Floating Navigation Menu', 'books' ) . '</strong>' ),
		'std'      => '0',
	],
	[
		'id'         => 'sticky_responsive_nav',
		'type'       => 'switch',
		'title'      => esc_html__( 'Floating Navigation Responsive', 'books' ),
		'sub_desc'   => wp_kses( __( 'Use this button to Show or Hide the <strong>Floating Navigation Menu</strong> on Responsive screen.', 'books' ), [ 'strong' => '' ] ),
		'std'        => '0',
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'sticky_nav',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],

	[
		'id'       => 'header_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set header margin from here.', 'books' ),
		'left'     => false,
		'right'    => false,
		'std'      => [
			'top'    => '0',
			'bottom' => '0',
		],
	],
	[
		'id'       => 'header_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set header padding from here.', 'books' ),
		'left'     => false,
		'right'    => false,
		'std'      => [
			'top'    => books_px2rem( '43px' ),
			'bottom' => books_px2rem( '43px' ),
		],
	],

	[
		'id'       => 'header_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'books' ),
		'sub_desc' => esc_html__( 'Select border.', 'books' ),
	],

	[
		'id'       => 'header_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Header Background', 'books' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'books' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '#fafafa',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],

	[
		'id'       => 'hide_logo',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show/Hide Logo', 'books' ),
		'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Logo</strong> completely.', 'books' ), [ 'strong' => '' ] ),
		'std'      => '1',
	],

	[
		'id'       => 'hide_search_box',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show/Hide Search Box', 'books' ),
		'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Search Box</strong> completely.', 'books' ), [ 'strong' => '' ] ),
		'std'      => '1',
	],

	[
		'id'         => 'header_social_icons',
		'title'      => esc_html__( 'Header Social Icons', 'books' ),
		'sub_desc'   => esc_html__( 'Add Social Media icons in header.', 'books' ),
		'type'       => 'group',
		'groupname'  => esc_html__( 'Header Icon', 'books' ), // Group name.
		'subfields'  => [
			[
				'id'    => 'header_icon_title',
				'type'  => 'text',
				'title' => esc_html__( 'Title', 'books' ),
			],
			[
				'id'    => 'header_icon',
				'type'  => 'icon_select',
				'title' => esc_html__( 'Icon', 'books' ),
			],
			[
				'id'    => 'header_icon_link',
				'type'  => 'text',
				'title' => esc_html__( 'URL', 'books' ),
			],
			[
				'id'    => 'header_icon_bgcolor',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon background color', 'books' ),
			],
			[
				'id'    => 'header_icon_hover_bgcolor',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon background hover color', 'books' ),
			],
			[
				'id'    => 'header_icon_color',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon color', 'books' ),
			],
			[
				'id'    => 'header_icon_hover_color',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon hover color', 'books' ),
			],
			[
				'id'    => 'header_icon_margin',
				'type'  => 'margin',
				'title' => esc_html__( 'Header icon Margin', 'books' ),
			],
			[
				'id'    => 'header_icon_padding',
				'type'  => 'margin',
				'title' => esc_html__( 'Header icon Padding', 'books' ),
			],
			[
				'id'    => 'header_icon_border_radius',
				'type'  => 'text',
				'class' => 'small-text',
				'title' => esc_html__( 'Header icon border radius', 'books' ),
				'args'  => [ 'type' => 'number' ],
			],
		],
		'std'        => [
			'facebook'  => [
				'group_title'               => 'Facebook',
				'group_sort'                => '1',
				'header_icon_title'         => 'Facebook',
				'header_icon'               => 'facebook-official',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#484055',
				'header_icon_hover_color'   => books_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				],
				'header_icon_padding'       => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_border_radius' => '0',
			],
			'youtube'   => [
				'group_title'               => 'Youtube',
				'group_sort'                => '2',
				'header_icon_title'         => 'Youtube',
				'header_icon'               => 'youtube-play',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#484055',
				'header_icon_hover_color'   => books_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				],
				'header_icon_padding'       => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_border_radius' => '0',
			],
			'twitter'   => [
				'group_title'               => 'Twitter',
				'group_sort'                => '3',
				'header_icon_title'         => 'Twitter',
				'header_icon'               => 'twitter',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#484055',
				'header_icon_hover_color'   => books_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				],
				'header_icon_padding'       => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_border_radius' => '0',
			],
			'pinterest' => [
				'group_title'               => 'Pinterest',
				'group_sort'                => '4',
				'header_icon_title'         => 'Pinterest',
				'header_icon'               => 'pinterest',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#484055',
				'header_icon_hover_color'   => books_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				],
				'header_icon_padding'       => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_border_radius' => '0',
			],
			'instagram' => [
				'group_title'               => 'Instagram',
				'group_sort'                => '5',
				'header_icon_title'         => 'Instagram',
				'header_icon'               => 'instagram',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#484055',
				'header_icon_hover_color'   => books_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				],
				'header_icon_padding'       => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_border_radius' => '0',
			],

		],
		'dependency' => $header_layout2_only,
	],

	// Nav Settings.
	[
		'id'    => 'header_nav_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Nav Settings', 'books' ),
	],
	[
		'id'         => 'main_nav_bg_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Nav Background Color', 'books' ),
		'sub_desc'   => esc_html__( 'Select background color for navigation from here.', 'books' ),
		'std'        => '#fafafa',
		'dependency' => $header_layout2_only,
	],
	[
		'id'       => 'main_nav_dropdown_bg',
		'type'     => 'color',
		'title'    => esc_html__( 'Dropdown Background Color', 'books' ),
		'sub_desc' => esc_html__( 'Select dropdown background color for navigation from here.', 'books' ),
		'std'      => '#ffffff',
	],
	[
		'id'       => 'main_navigation_dropdown_color',
		'type'     => 'color',
		'title'    => esc_html__( 'Dropdown Text Color', 'books' ),
		'sub_desc' => esc_html__( 'Select dropdown text color for navigation from here.', 'books' ),
		'std'      => '#484055',
	],
	[
		'id'       => 'main_navigation_dropdown_hover_color',
		'type'     => 'color',
		'title'    => esc_html__( 'Dropdown Text Hover Color', 'books' ),
		'sub_desc' => esc_html__( 'Select dropdown text hover color for navigation from here.', 'books' ),
		'std'      => '#81d1d4',
	],

	// Header layout Default.
	[
		'id'         => 'header_nav_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Nav Margin', 'books' ),
		'sub_desc'   => esc_html__( 'Set nav margin from here.', 'books' ),
		'std'        => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
		'dependency' => $default_header_only,
	],
	[
		'id'         => 'header_nav_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Nav Padding', 'books' ),
		'sub_desc'   => esc_html__( 'Set nav padding from here.', 'books' ),
		'std'        => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
		'dependency' => $default_header_only,
	],

	// Header layout 2.
	[
		'id'         => 'header2_nav_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Nav Margin', 'books' ),
		'sub_desc'   => esc_html__( 'Set nav margin from here.', 'books' ),
		'std'        => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => books_px2rem( '40' ),
			'left'   => '0',
		],
		'dependency' => $header_layout2_only,
	],
	[
		'id'         => 'header2_nav_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Nav Padding', 'books' ),
		'sub_desc'   => esc_html__( 'Set nav padding from here.', 'books' ),
		'std'        => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
		'dependency' => $header_layout2_only,
	],

];
