<?php
/**
 * HomePage Blog Section
 *
 * @package Books
 */

$menus['homepage']['child']['homepage-blog'] = [
	'title' => esc_html__( 'Blog', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the Blog Section.', 'books' ),
];

$sections['homepage-blog'] = [

	[
		'id'       => 'blog_custom_title',
		'type'     => 'heading_text',
		'title'    => esc_html__( 'Blog Title', 'books' ),
		'sub_desc' => esc_html__( 'Enter title for blog section.', 'books' ),
		'std'      => [
			'heading' => 'Blog',
			'tag'     => 'h2',
		],
	],

	[
		'id'       => 'blog_post_num',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Number of Posts', 'books' ),
		'sub_desc' => esc_html__( 'Enter number of posts for blog section.', 'books' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '3',
	],
	[
		'id'       => 'blog_excerpt_length',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Excerpt Length', 'books' ),
		'sub_desc' => esc_html__( 'Enter excerpt length for blog section.', 'books' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '25',
	],
	[
		'id'       => 'blog_meta_info',
		'type'     => 'multi_checkbox',
		'title'    => esc_html__( 'Meta Info', 'books' ),
		'sub_desc' => esc_html__( 'Show or hide post meta info.', 'books' ),
		'options'  => [
			'date'   => esc_html__( 'Date', 'books' ),
			'author' => esc_html__( 'Author Name', 'books' ),
		],
		'std'      => [
			'date',
			'author',
		],
	],

	[
		'id'    => 'blog_typo_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Typography Settings', 'books' ),
	],

	[
		'id'    => 'blog_section_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Section Title Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Blog',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '36px',
			'line-height'    => '1',
			'color'          => '#484055',
			'additional-css' => 'letter-spacing: -0.504px;',
			'css-selectors'  => '.blog-section .section-title',
		],
	],

	[
		'id'    => 'blog_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Post Title Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Post Title',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '24px',
			'line-height'    => '1.25',
			'margin-top'     => books_px2rem( '13px' ),
			'color'          => '#484055',
			'additional-css' => 'letter-spacing: -0.11px;',
			'css-selectors'  => '.blog-wrapper .title, .blog-wrapper .title a',
		],
	],
	[
		'id'    => 'blog_meta_info_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Meta info Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Meta info',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '500',
			'font-size'      => '11px',
			'color'          => '#a19da7',
			'additional-css' => 'text-transform: uppercase; letter-spacing: 2.684px;',
			'css-selectors'  => '.blog-wrapper .post-meta, .blog-wrapper .post-meta a',
		],
	],
	[
		'id'    => 'blog_content_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Content Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Blog Content',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '500',
			'font-size'      => '13px',
			'line-height'    => '1.538',
			'margin-top'     => books_px2rem( '13px' ),
			'color'          => '#a19da7',
			'additional-css' => 'letter-spacing: 0.224px;',
			'css-selectors'  => '.blog-wrapper .front-view-content',
		],
	],

	[
		'id'    => 'blog_styling_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Styling Settings', 'books' ),
	],

	[
		'id'       => 'blog_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Section Background', 'books' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'books' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'blog_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set blog section margin from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'blog_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set blog section padding from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '94px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],

];
