<?php
/**
 * HomePage Featured Section
 *
 * @package Books
 */

$menus['homepage']['child']['homepage-featured'] = [
	'title' => esc_html__( 'Featured', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the Featured Section.', 'books' ),
];

$sections['homepage-featured'] = [

	[
		'id'    => 'featured_category',
		'type'  => 'select',
		'title' => esc_html__( 'Select Category', 'books' ),
		'data'  => 'category_slug',
		'args'  => [
			'include_latest' => 0,
			'hide_empty'     => 0,
			'taxonomy'       => 'product_cat',
		],
	],

	[
		'id'       => 'featured_custom_title',
		'type'     => 'heading_text',
		'title'    => esc_html__( 'Show Custom Title', 'books' ),
		'sub_desc' => esc_html__( 'Enter custom title to show in top of posts section. Leave blank to show category title.', 'books' ),
		'std'      => [
			'heading' => 'Featured',
			'tag'     => 'h2',
		],
	],

	[
		'id'       => 'featured_post_num',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Number of Posts', 'books' ),
		'sub_desc' => esc_html__( 'Enter number of posts for featured section.', 'books' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '4',
	],
	[
		'id'       => 'featured_meta_info',
		'type'     => 'multi_checkbox',
		'title'    => esc_html__( 'Meta Info', 'books' ),
		'sub_desc' => esc_html__( 'Show or hide post meta info.', 'books' ),
		'options'  => [
			'date'   => esc_html__( 'Date', 'books' ),
			'author' => esc_html__( 'Author Name', 'books' ),
		],
		'std'      => [
			'author',
		],
	],
	[
		'id'       => 'featured_thumb_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'books' ),
		'sub_desc' => esc_html__( 'Enter border radius for featured thumbnail.', 'books' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '5',
	],
	[
		'id'       => 'featured_thumb_shadow',
		'type'     => 'switch',
		'title'    => esc_html__( 'Box Shadow', 'books' ),
		'sub_desc' => esc_html__( 'Enable or Disable box shadow of thumbnail from here.', 'books' ),
		'std'      => '1',
	],

	[
		'id'    => 'featured_typo_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Typography Settings', 'books' ),
	],

	[
		'id'    => 'featured_section_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Section Title Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Section Title',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '36px',
			'line-height'    => '1',
			'margin-bottom'  => books_px2rem( '63px' ),
			'color'          => '#484055',
			'letter-spacing' => '-0.504px',
			'css-selectors'  => '.featured-section .section-title, .featured-section .section-title a',
		],
	],
	[
		'id'    => 'featured_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Title Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Post Title',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '20px',
			'color'          => '#484055',
			'letter-spacing' => '-0.28px',
			'css-selectors'  => '.featured-section .section-wrapper .title a',
		],
	],
	[
		'id'    => 'featured_meta_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Meta Info Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Meta info',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '500',
			'font-size'      => '11px',
			'line-height'    => '1',
			'margin-top'     => '10px',
			'color'          => '#a19da7',
			'letter-spacing' => '2.684px',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.featured-section .section-wrapper .post-meta, .featured-section .section-wrapper .post-meta a, .woocommerce ul.products li.product .price, .woocommerce div.product p.price',
		],
	],

	[
		'id'    => 'featured_styling_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Styling Settings', 'books' ),
	],

	[
		'id'       => 'featured_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Section Background', 'books' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'books' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'featured_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set featured section margin from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'featured_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set featured section padding from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '117px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],

];
