<?php
/**
 * HomePage Slider Section
 *
 * @package Books
 */

$menus['homepage']['child']['homepage-slider'] = [
	'title' => esc_html__( 'Slider', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the Slider Section.', 'books' ),
];

$sections['homepage-slider'] = [

	[
		'id'       => 'slider_category',
		'type'     => 'select',
		'multiple' => 'multiple',
		'title'    => esc_html__( 'Category', 'books' ),
		'data'     => 'category_slug',
		'args'     => [
			'include_latest' => 0,
			'hide_empty'     => 0,
			'taxonomy'       => 'product_cat',
		],
	],

	[
		'id'       => 'slider_autoplay',
		'type'     => 'switch',
		'title'    => esc_html__( 'Autoplay', 'books' ),
		'sub_desc' => esc_html__( 'Enable/Disable autoplay slider.', 'books' ),
		'std'      => '1',
	],
	[
		'id'       => 'slider_post_num',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Number of Posts', 'books' ),
		'sub_desc' => esc_html__( 'Enter number of posts for slider section.', 'books' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '5',
	],
	[
		'id'       => 'slider_meta_info',
		'type'     => 'multi_checkbox',
		'title'    => esc_html__( 'Meta Info', 'books' ),
		'sub_desc' => esc_html__( 'Show or hide post meta info.', 'books' ),
		'options'  => [
			'date'   => esc_html__( 'Date', 'books' ),
			'author' => esc_html__( 'Author Name', 'books' ),
		],
		'std'      => [
			'author',
		],
	],
	[
		'id'       => 'slider_excerpt_length',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Excerpt Length', 'books' ),
		'sub_desc' => esc_html__( 'Enter excerpt length for slider section.', 'books' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '30',
	],
	[
		'id'       => 'slider_items_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'books' ),
		'sub_desc' => esc_html__( 'Enter border radius for slider items and thumbnail.', 'books' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '5',
	],
	[
		'id'       => 'slider_items_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Slider Item Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set slider item padding from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '55px' ),
			'right'  => books_px2rem( '55px' ),
			'bottom' => books_px2rem( '35px' ),
			'left'   => books_px2rem( '55px' ),
		],
	],

	[
		'id'    => 'slider_typo_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Typography Settings', 'books' ),
	],

	[
		'id'    => 'slider_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Title Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Title',
			'preview-color'  => 'dark',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '36px',
			'color'          => '#ffffff',
			'additional-css' => 'letter-spacing: -0.504px;',
			'css-selectors'  => '.slider-wrapper .title a',
		],
	],
	[
		'id'    => 'slider_meta_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Meta Info Font', 'books' ),
		'std'   => [
			'preview-text'  => 'Meta info',
			'preview-color' => 'dark',
			'font-family'   => 'Montserrat',
			'font-weight'   => '600',
			'font-size'     => '15px',
			'line-height'   => '1',
			'margin-top'    => '10px',
			'color'         => '#ffffff',
			'css-selectors' => '.slider-wrapper .post-meta, .slider-wrapper .post-meta a',
		],
	],
	[
		'id'    => 'slider_excerpt',
		'type'  => 'typography',
		'title' => esc_html__( 'Content Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Content',
			'preview-color'  => 'dark',
			'font-family'    => 'Montserrat',
			'font-weight'    => '500',
			'font-size'      => '13px',
			'line-height'    => '1.538',
			'margin-top'     => books_px2rem( '13px' ),
			'color'          => '#ffffff',
			'additional-css' => 'opacity: 0.8;',
			'css-selectors'  => '.slider-wrapper .front-view-content',
		],
	],

	[
		'id'    => 'slider_styling_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Styling Settings', 'books' ),
	],

	[
		'id'       => 'slider_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Section Background', 'books' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'books' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'slider_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set slider section margin from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'slider_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set slider section padding from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '106px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],

];
