<?php
/**
 * Single AuthorBox
 *
 * @package Books
 */

$menus['single-authorbox'] = [
	'icon'  => 'fa-pencil',
	'title' => esc_html__( 'Author Box', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of Author box in single posts page.', 'books' ),
];

$sections['single-authorbox'] = [

	[
		'id'    => 'authorbox_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author box Settings', 'books' ),
	],
	[
		'id'       => 'authorbox_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Author box Background', 'books' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image for subscribe box from here.', 'books' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '#ffffff',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'author_box_title',
		'type'     => 'text',
		'title'    => esc_html__( 'Author Box Title', 'books' ),
		'sub_desc' => esc_html__( 'Enter author box title.', 'books' ),
		'std'      => '',
	],
	[
		'id'       => 'authorbox_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set Author box margin from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '32px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'authorbox_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set Author box padding from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '53px' ),
			'right'  => books_px2rem( '48px' ),
			'bottom' => books_px2rem( '50px' ),
			'left'   => books_px2rem( '48px' ),
		],
	],
	[
		'id'       => 'authorbox_shadow',
		'type'     => 'switch',
		'title'    => esc_html__( 'Box Shadow', 'books' ),
		'sub_desc' => esc_html__( 'Enable/Disable shadow from here', 'books' ),
		'std'      => '1',
	],
	[
		'id'       => 'authorbox_border',
		'type'     => 'border2',
		'title'    => esc_html__( 'Border', 'books' ),
		'sub_desc' => esc_html__( 'Select border', 'books' ),
	],
	[
		'id'       => 'authorbox_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'books' ),
		'sub_desc' => esc_html__( 'Author box border radius.', 'books' ),
		'std'      => '5',
		'args'     => [ 'type' => 'number' ],
	],

	[
		'id'    => 'authorbox_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Box Title Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Author Box Title Font',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '28px',
			'line-height'    => '1',
			'color'          => '#484055',
			'letter-spacing' => '-0.392px',
			'css-selectors'  => '.postauthor h4',
		],
	],
	[
		'id'    => 'authorbox_author_name_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Name Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Author Name Font',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '18px',
			'color'          => '#484055',
			'additional-css' => 'text-transform: capitalize;',
			'css-selectors'  => '.postauthor h5, .postauthor h5 a',
		],
	],
	[
		'id'    => 'authorbox_text_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Text Font', 'books' ),
		'std'   => [
			'preview-text'  => 'Author Text Font',
			'preview-color' => 'light',
			'font-family'   => 'Montserrat',
			'font-weight'   => '500',
			'font-size'     => '14px',
			'line-height'   => '1.857',
			'margin-top'    => '10px',
			'color'         => '#6d6677',
			'css-selectors' => '.postauthor p',
		],
	],

	[
		'id'    => 'author_img_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author Image Settings', 'books' ),
	],
	[
		'id'       => 'author_box_image',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Author Image', 'books' ),
		'sub_desc' => esc_html__( 'Use this button to show/hide author image.', 'books' ),
		'std'      => '1',
	],
	[
		'id'       => 'single_author_image_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set Author image margin from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => books_px2rem( '32px' ),
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'single_author_image_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'books' ),
		'sub_desc' => esc_html__( 'Author image border radius.', 'books' ),
		'std'      => '102',
		'args'     => [ 'type' => 'number' ],
	],

];
