<?php
/**
 * Single Comments
 *
 * @package Books
 */

$menus['single-comments'] = [
	'icon'  => 'fa-comment-o',
	'title' => esc_html__( 'Comments Section', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of Comments box in single posts page.', 'books' ),
];

$author_dependency = [
	'relation' => 'and',
	[
		'field'      => 'author_comment',
		'value'      => '1',
		'comparison' => '==',
	],
];

$sections['single-comments'] = [

	[
		'id'    => 'comments_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'General Settings', 'books' ),
	],
	[
		'id'       => 'mts_comment_date',
		'type'     => 'switch',
		'title'    => esc_html__( 'Date in Comments', 'books' ),
		'sub_desc' => esc_html__( 'Use this button to show the date for comments.', 'books' ),
		'std'      => '1',
	],
	[
		'id'       => 'comments_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set Comments box margin from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '25px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'comments_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set Comments box padding from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],

	[
		'id'    => 'comments_list_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'List Settings', 'books' ),
	],
	[
		'id'       => 'comments_list_image_size',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Comment Image Size', 'books' ),
		'sub_desc' => esc_html__( 'Set comment image size from here.', 'books' ),
		'std'      => '56',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'       => 'comments_list_image_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Image Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set image margin from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => books_px2rem( '24px' ),
			'bottom' => books_px2rem( '10px' ),
			'left'   => '0',
		],
	],
	[
		'id'       => 'comments_list_image_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Comment Image Border Radius', 'books' ),
		'sub_desc' => esc_html__( 'Set comment image border radius from here.', 'books' ),
		'std'      => '50',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'       => 'comments_list_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Comment Border', 'books' ),
		'sub_desc' => esc_html__( 'Manage comment list border from here.', 'books' ),
		'std'      => [
			'color'     => '#ddddde',
			'direction' => 'bottom',
			'size'      => 1,
			'style'     => 'solid',
		],
	],
	[
		'id'       => 'comments_list_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Comment Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set Comments margin from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'comments_list_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Comment Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set Comments padding from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '25px' ),
			'right'  => '0',
			'bottom' => books_px2rem( '35px' ),
			'left'   => '0',
		],
	],

	[
		'id'    => 'comments_author_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author Comments Settings', 'books' ),
	],

	[
		'id'       => 'author_comment',
		'type'     => 'switch',
		'title'    => esc_html__( 'Highlight Author Comment', 'books' ),
		'sub_desc' => esc_html__( 'Use this button to highlight author comments.', 'books' ),
		'std'      => '1',
	],
	[
		'id'         => 'author_comment_bg',
		'type'       => 'color',
		'title'      => esc_html__( 'Author Comment Background', 'books' ),
		'sub_desc'   => esc_html__( 'Use this option to change background color.', 'books' ),
		'std'        => '#ffffff',
		'dependency' => $author_dependency,
	],
	[
		'id'         => 'comments_list_author_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Author Comment Margin', 'books' ),
		'sub_desc'   => esc_html__( 'Set author comments margin from here.', 'books' ),
		'std'        => [
			'top'    => books_px2rem( '25px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
		'dependency' => $author_dependency,
	],
	[
		'id'         => 'comments_list_author_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Author Comment Padding', 'books' ),
		'sub_desc'   => esc_html__( 'Set author comments padding from here.', 'books' ),
		'std'        => [
			'top'    => books_px2rem( '24px' ),
			'right'  => books_px2rem( '30px' ),
			'bottom' => books_px2rem( '24px' ),
			'left'   => books_px2rem( '30px' ),
		],
		'dependency' => $author_dependency,
	],

	[
		'id'    => 'comments_typo_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Comments Typography Settings', 'books' ),
	],

	[
		'id'    => 'comments_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Comments Title Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Author Name',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '15px',
			'color'          => '#484055',
			'additional-css' => 'text-transform: capitalize;',
			'css-selectors'  => '#comments .fn, #comments .fn a',
		],
	],
	[
		'id'    => 'comments_meta_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Comments Meta Info Font', 'books' ),
		'std'   => [
			'preview-text'  => '2 days Ago',
			'preview-color' => 'light',
			'font-family'   => 'Montserrat',
			'font-weight'   => '400',
			'font-size'     => '15px',
			'color'         => '#484055',
			'css-selectors' => '#comments .ago',
		],
	],
	[
		'id'    => 'comments_text_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Comments Text Font', 'books' ),
		'std'   => [
			'preview-text'  => 'Comments Text',
			'preview-color' => 'light',
			'font-family'   => 'Montserrat',
			'font-weight'   => '500',
			'font-size'     => '13px',
			'line-height'   => '1.77',
			'margin-top'    => books_px2rem( '11px' ),
			'color'         => '#6c6576',
			'css-selectors' => '.commentmetadata .commenttext p',
		],
	],
];
