<?php
/**
 * Single Related Posts
 *
 * @package Books
 */

$menus['single-related'] = [
	'icon'  => 'fa-arrows-alt',
	'title' => esc_html__( 'Related Posts', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of related posts in single posts page.', 'books' ),
];

$sections['single-related'] = [

	[
		'id'       => 'related_posts_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Related Posts Background', 'books' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'books' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],

	[
		'id'       => 'related_posts_layouts',
		'type'     => 'radio_img',
		'title'    => esc_html__( 'Related Posts Layouts', 'books' ),
		'sub_desc' => esc_html__( 'Choose the Related Posts layouts for your site.', 'books' ),
		'options'  => [
			'default'  => [ 'img' => $uri . 'related/r1.jpg' ],
			'related2' => [ 'img' => $uri . 'related/r2.jpg' ],
			'related3' => [ 'img' => $uri . 'related/r3.jpg' ],
			'related5' => [ 'img' => $uri . 'related/r5.jpg' ],
			'related6' => [ 'img' => $uri . 'related/r6.jpg' ],
		],
		'std'      => 'default',
	],

	[
		'id'         => 'related_posts_grid',
		'type'       => 'select',
		'class'      => 'small',
		'title'      => esc_html__( 'Grid', 'books' ),
		'sub_desc'   => esc_html__( 'Select the number of grid for Related Posts.', 'books' ),
		'options'    => [
			'grid2' => esc_html__( '2', 'books' ),
			'grid3' => esc_html__( '3', 'books' ),
			'grid4' => esc_html__( '4', 'books' ),
			'grid5' => esc_html__( '5', 'books' ),
			'grid6' => esc_html__( '6', 'books' ),
		],
		'std'        => 'grid3',
		'dependency' => [
			'relation' => 'or',
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'default',
				'comparison' => '==',
			],
		],
	],
	[
		'id'       => 'related_post_title',
		'type'     => 'text',
		'title'    => esc_html__( 'Related Posts Title', 'books' ),
		'sub_desc' => esc_html__( 'Enter the title text to show in the related posts section.', 'books' ),
		'std'      => 'Related Posts',
	],
	[
		'id'       => 'mts_related_postsnum',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Number of related posts', 'books' ),
		'sub_desc' => esc_html__( 'Enter the number of posts to show in the related posts section.', 'books' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '3',
	],

	[
		'id'         => 'related_posts_adcode',
		'type'       => 'ace_editor',
		'mode'       => 'html',
		'title'      => esc_html__( 'Related Posts Ad', 'books' ),
		'sub_desc'   => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads in Related Posts Area.', 'books' ),
		'dependency' => [
			'relation' => 'or',
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related5',
				'comparison' => '==',
			],
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related6',
				'comparison' => '==',
			],
		],
	],

	[
		'id'       => 'related_posts_position',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Related Posts Position', 'books' ),
		'sub_desc' => esc_html__( 'Choose the position for related posts, below content will be Full width', 'books' ),
		'options'  => [
			'default' => esc_html__( 'Default', 'books' ),
			'full'    => esc_html__( 'Below Content', 'books' ),
		],
		'std'      => 'default',
	],
	[
		'id'       => 'related_post_image_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Post Image Border Radius', 'books' ),
		'sub_desc' => esc_html__( 'Related post image border radius.', 'books' ),
		'std'      => '5',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'       => 'related_post_meta_info',
		'type'     => 'multi_checkbox',
		'title'    => esc_html__( 'Post Meta Info', 'books' ),
		'sub_desc' => esc_html__( 'Show or hide post meta info.', 'books' ),
		'options'  => [
			'time'     => esc_html__( 'Time/Date', 'books' ),
			'author'   => esc_html__( 'Author Name', 'books' ),
			'category' => esc_html__( 'Category', 'books' ),
			'comment'  => esc_html__( 'Comments', 'books' ),
			'readmore' => esc_html__( 'Read More', 'books' ),
		],
		'std'      => [
			'time',
			'author',
		],
	],

	[
		'id'       => 'related_show_excerpt',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show/Hide Excerpt', 'books' ),
		'sub_desc' => esc_html__( 'Enable or disable the excerpt to show in the related posts section.', 'books' ),
		'std'      => '1',
	],
	[
		'id'         => 'related_excerpt_length',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Excerpt Length', 'books' ),
		'sub_desc'   => esc_html__( 'Enter excerpt length to show in the related posts section.', 'books' ),
		'args'       => [ 'type' => 'number' ],
		'std'        => '26',
		'dependency' => [
			'relation' => 'or',
			[
				'field'      => 'related_show_excerpt',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],

	[
		'id'       => 'related_posts_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set related posts margin from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '71px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'related_posts_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set related posts padding from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],

	[
		'id'       => 'related_posts_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'books' ),
		'sub_desc' => esc_html__( 'Select border', 'books' ),
	],

	[
		'id'    => 'related_posts_meta_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Related Posts Meta Info', 'books' ),
		'std'   => [
			'preview-text'   => 'Related Posts Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '500',
			'font-size'      => '9px',
			'color'          => '#a19da7',
			'letter-spacing' => '2.196px',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.related-posts .post-info, .related-posts .post-info a, .related-posts .readMore a',
		],
	],
	[
		'id'    => 'related_posts_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Related Posts Title', 'books' ),
		'std'   => [
			'preview-text'   => 'Related Posts Title',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '18px',
			'line-height'    => '1.333',
			'color'          => '#484055',
			'margin-top'     => books_px2rem( '23px' ),
			'letter-spacing' => '-0.252px',
			'css-selectors'  => '.related-posts .title a',
		],
	],
	[
		'id'    => 'related_posts_excerpt_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Related Posts Excerpt', 'books' ),
		'std'   => [
			'preview-text'  => 'Related Posts Excerpt Font',
			'preview-color' => 'light',
			'font-family'   => 'Montserrat',
			'font-weight'   => '500',
			'font-size'     => '13px',
			'line-height'   => '1.769',
			'color'         => '#a19da7',
			'margin-top'    => books_px2rem( '12px' ),
			'css-selectors' => '.related-posts .front-view-content',
		],
	],

	[
		'id'    => 'related_posts_article_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Related Posts Articles', 'books' ),
	],

	[
		'id'       => 'related_article_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Related Posts Background', 'books' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'books' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'related_article_shadow',
		'type'     => 'switch',
		'title'    => esc_html__( 'Box Shadow', 'books' ),
		'sub_desc' => esc_html__( 'Enable/Disable shadow from here', 'books' ),
		'std'      => '1',
	],
	[
		'id'       => 'related_article_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Articles Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set related posts articles padding from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'related_article_text_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Articles Text Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set related posts articles text padding from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '23px' ),
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],

];
