<?php
/**
 * Single Styling
 *
 * @package Books
 */

$menus['single-styling'] = [
	'icon'  => 'fa-paint-brush',
	'title' => esc_html__( 'Single Styling', 'books' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of your single posts page.', 'books' ),
];

$sections['single-styling'] = [

	[
		'id'    => 'single_title_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Single Titles Styling', 'books' ),
	],

	[
		'id'       => 'single_title_alignment',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Single Page Title Alignment', 'books' ),
		'sub_desc' => esc_html__( 'Choose the single page title alignment', 'books' ),
		'options'  => [
			'left'   => esc_html__( 'Left', 'books' ),
			'center' => esc_html__( 'Center', 'books' ),
			'right'  => esc_html__( 'Right', 'books' ),
		],
		'std'      => 'left',
	],

	[
		'id'       => 'single_title_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Single Page Title Background Color', 'books' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'books' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'single_title_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Single Page Title Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set single page title padding from here.', 'books' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'single_title_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'books' ),
		'sub_desc' => esc_html__( 'Select border', 'books' ),
	],

	[
		'id'    => 'mts_single_styling_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Single Styling', 'books' ),
	],

	[
		'id'       => 'single_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Background', 'books' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image of Single, Page, Archive, Search, Category and 404 Page from here.', 'books' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '#ffffff',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],

	[
		'id'       => 'mts_single_styling_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Single Margin', 'books' ),
		'sub_desc' => esc_html__( 'Set single post margin from here.', 'books' ),
		'left'     => false,
		'right'    => false,
		'std'      => [
			'top'    => '0',
			'bottom' => books_px2rem( '36px' ),
		],
	],
	[
		'id'       => 'mts_single_styling_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Single Padding', 'books' ),
		'sub_desc' => esc_html__( 'Set single post padding from here.', 'books' ),
		'std'      => [
			'top'    => books_px2rem( '40px' ),
			'right'  => books_px2rem( '50px' ),
			'bottom' => '0',
			'left'   => books_px2rem( '50px' ),
		],
	],
	[
		'id'       => 'single_styling_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'books' ),
		'sub_desc' => esc_html__( 'Select border', 'books' ),
	],

	[
		'id'       => 'single_styling_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'books' ),
		'sub_desc' => esc_html__( 'Enter border radius for single post.', 'books' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '5',
	],
	[
		'id'       => 'single_styling_shadow',
		'type'     => 'switch',
		'title'    => esc_html__( 'Box Shadow', 'books' ),
		'sub_desc' => esc_html__( 'Enable or Disable box shadow from here.', 'books' ),
		'std'      => '1',
	],

	[
		'id'    => 'mts_single_meta_info_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Single Meta Info Font', 'books' ),
		'std'   => [
			'preview-text'   => 'Post Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '13px',
			'color'          => '#a39faa',
			'letter-spacing' => '3.172px',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.single_post .post-info, .single_post .post-info a',
		],
	],
	[
		'id'    => 'single_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Single Post Title', 'books' ),
		'std'   => [
			'preview-text'   => 'Single Article Title',
			'preview-color'  => 'light',
			'font-family'    => 'Montserrat',
			'font-weight'    => '700',
			'font-size'      => '36px',
			'line-height'    => '1.11',
			'margin-top'     => books_px2rem( '27px' ),
			'margin-bottom'  => books_px2rem( '20px' ),
			'color'          => '#484055',
			'letter-spacing' => '-0.504px',
			'css-selectors'  => '.single-title',
		],
	],

];
