<?php // @codingStandardsIgnoreLine
/**
 * Homepage Section - Blog
 *
 * @package Books
 */

defined( 'WPINC' ) || exit;

/**
 * HomePage Blog
 */
class Home_Blog extends Books_Homepage {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'books_blog_post_thumb', 'get_thumbnail', 10, 1 );
		$this->add_action( 'books_blog_meta_info', 'get_meta_info', 10, 2 );
		$this->add_action( 'books_blog_post_content', 'get_post_title', 20 );
		$this->add_action( 'books_blog_post_content', 'get_content', 30, 1 );
		$this->get_blog_posts();
	}

	/**
	 * Get selected Posts
	 */
	public function get_blog_posts() {

		$blog_post_meta = books_get_settings( 'blog_meta_info' );
		$blog_post_num  = books_get_settings( 'blog_post_num' );
		$excerpt_length = books_get_settings( 'blog_excerpt_length' );

		$new_args = [
			'post_type'      => 'post',
			'posts_per_page' => $blog_post_num,
		];

		$args  = $this->get_default_args( $new_args );
		$query = new WP_Query( $args );

		?>
		<section class="blog-section">

			<div class="container">

				<?php

				echo $this->get_section_title( books_get_settings( 'blog_custom_title' ) ); // @codingStandardsIgnoreLine

				echo '<ul class="blog-wrapper">';

				if ( ! $query->have_posts() ) {
					get_template_part( 'template-parts/no', 'posts' );
				}

				while ( $query->have_posts() ) :
					$query->the_post();
					?>

					<li <?php post_class(); ?> id="post-<?php the_ID(); ?>">

						<article class="blog-post-wrap">

							<?php books_action( 'blog_post_thumb', 'books-blog' ); ?>

							<div class="wrapper">
								<?php
									books_action( 'blog_meta_info', $blog_post_meta, true );
									books_action( 'blog_post_content', $excerpt_length );
								?>
							</div>

						</article>

					</li>

					<?php
					endwhile;
					wp_reset_postdata();

				echo '</ul>';
				?>

			</div><!-- .container -->

		</section>
		<?php
	}

}

// Init.
new Home_Blog();
