<?php // @codingStandardsIgnoreLine
/**
 * Homepage Section - Categories
 *
 * @package Books
 */

defined( 'WPINC' ) || exit;

/**
 * HomePage Categories
 */
class Home_Categories extends Books_Homepage {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->get_categories();
	}

	/**
	 * Categories structure
	 */
	public function get_categories() {

		$count      = 0;
		$new_args   = [];
		$categories = books_get_settings( 'home_categories_list' );

		if ( ! $categories || ! is_array( $categories ) ) {
			return;
		}

		?>
		<section class="categories-section">

			<div class="container clearfix">

				<div class="categories-wrapper">
				<?php

				foreach ( $categories as $category ) {

					$term_link = get_term_link( $category['home_product_category'], 'product_cat' );

					if ( ! $term_link || is_wp_error( $term_link ) ) {
						continue;
					}

					$term_obj = get_term_by( 'slug', $category['home_product_category'], 'product_cat' );

					$new_args = [
						'tax_query' => [
							[
								'taxonomy' => 'product_cat',
								'field'    => 'slug',
								'terms'    => $category['home_product_category'],
							],
						],
					];

					$args  = $this->get_default_args( $new_args );
					$query = new WP_Query( $args );

					printf(
						'<a href="%3$s" class="cat-item-wrap cat-item-%1$s">
							<div class="icon">
								<i class="fa fa-%2$s"></i>
							</div>
							<div class="text-wrap">
								<div class="cat-name">%4$s</div>
								<div class="post-count">%5$s %6$s</div>
							</div>
						</a>',
						esc_html( ++$count ),
						esc_html( $category['home_category_icon'] ),
						esc_html( $term_link ),
						esc_html( $term_obj->name ),
						esc_html( $query->found_posts ),
						esc_html( $category['count_text'] )
					);

				}

				?>
				</div>

			</div><!-- .container -->

		</section>
		<?php
	}

}

// Init.
new Home_Categories();
