<?php // @codingStandardsIgnoreLine
/**
 * Homepage Section - Featured
 *
 * @package Books
 */

defined( 'WPINC' ) || exit;

/**
 * HomePage Featured
 */
class Home_Featured extends Books_Homepage {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'books_home_section_post_title', 'get_post_title', 10 );
		$this->add_action( 'books_home_section_meta_info', 'get_meta_info', 20, 1 );
		$this->add_action( 'books_home_section_thumbnail', 'get_thumbnail', 10, 1 );
		$this->add_action( 'books_home_read_more', 'get_custom_readmore' );
		$this->get_selected_posts();
	}

	/**
	 * Get selected Posts
	 *
	 * @param String $section name.
	 */
	public function get_selected_posts( $section = 'featured' ) {

		$featured_meta_info = books_get_settings( $section . '_meta_info' );
		$featured_post_num  = books_get_settings( $section . '_post_num' );
		$featured_cats      = books_get_settings( $section . '_category' );
		$new_args           = [];

		if ( $featured_cats ) {
			$new_args = [
				'posts_per_page' => $featured_post_num,
				'orderby'        => 'ID',
				'tax_query'      => [ // @codingStandardsIgnoreLine
					[
						'taxonomy' => 'product_cat',
						'field'    => 'slug',
						'terms'    => $featured_cats,
					],
				],
			];
		}

		$args  = $this->get_default_args( $new_args );
		$query = new WP_Query( $args );

		?>
		<section class="<?php echo esc_html( $section ); ?>-section">

			<div class="container">

				<?php

				echo $this->get_section_title( $section ); // @codingStandardsIgnoreLine

				echo '<ul class="section-wrapper">';

				if ( ! $query->have_posts() ) {
					get_template_part( 'template-parts/no', 'posts' );
				}

				while ( $query->have_posts() ) :
					$query->the_post();
					?>

					<li <?php post_class(); ?> id="post-<?php the_ID(); ?>">

						<div class="section-post-content">
							<?php
								books_action( 'home_section_post_title' );
								books_action( 'home_section_meta_info', $featured_meta_info );
							?>
						</div>

						<div class="section-post-thumb">
							<?php books_action( 'home_section_thumbnail', 'books-featured-section' ); ?>
							<?php books_action( 'home_read_more' ); ?>
						</div>

					</li>

					<?php
				endwhile;
				wp_reset_postdata();

				echo '</ul>';
				?>

			</div><!-- .container -->

		</section>
		<?php
	}

	/**
	 * Get section title
	 *
	 * @param String $section name.
	 */
	public function get_section_title( $section = 'featured' ) {

		$featured_cats = books_get_settings( $section . '_category' );
		$custom_title  = books_get_settings( $section . '_custom_title' );
		$term_link     = get_term_link( $featured_cats, 'product_cat' );

		$title = sprintf(
			'<%2$s class="section-title">%1$s</%2$s>',
			...array_values( $custom_title )
		);

		if ( ! $custom_title['heading'] ) {
			$title = sprintf(
				'<h2 class="section-title">
					<a href="%1$s">%2$s</a>
				</h2>',
				$term_link,
				$featured_cats
			);
		}

		return $title;
	}

}

// Init.
new Home_Featured();
