<?php // @codingStandardsIgnoreLine
/**
 * Homepage Section - Slider
 *
 * @package Books
 */

defined( 'WPINC' ) || exit;

/**
 * HomePage Slider
 */
class Home_Slider extends Books_Homepage {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'books_slider_thumbnail', 'get_thumbnail', 10, 1 );
		$this->add_action( 'books_slider_title', 'get_post_title', 10 );
		$this->add_action( 'books_slider_meta_info', 'get_meta_info', 20, 1 );
		$this->add_action( 'books_slider_content', 'get_rating', 10 );
		$this->add_action( 'books_slider_content', 'get_content', 20, 1 );
		$this->get_slider();
	}

	/**
	 * Slider structure
	 */
	public function get_slider() {

		$slider_meta_info = books_get_settings( 'slider_meta_info' );
		$slider_post_num  = books_get_settings( 'slider_post_num' );
		$slider_cats      = books_get_settings( 'slider_category' );
		$slider_excerpt   = books_get_settings( 'slider_excerpt_length' );
		$new_args         = [
			'posts_per_page' => $slider_post_num,
		];

		if ( $slider_cats ) {
			$new_args = [
				'posts_per_page' => $slider_post_num,
				'tax_query'      => [ // @codingStandardsIgnoreLine
					[
						'taxonomy' => 'product_cat',
						'field'    => 'slug',
						'terms'    => $slider_cats,
					],
				],
			];
		}

		$args  = $this->get_default_args( $new_args );
		$query = new WP_Query( $args );

		?>
		<section class="slider-section">

			<div class="slider-container clearfix loading">

				<?php

				echo '<ul class="slider-wrapper">';

				while ( $query->have_posts() ) :
					$query->the_post();

					$style = $this->get_gradient( get_the_ID() );

					?>

					<li <?php post_class(); ?> id="post-<?php the_ID(); ?>" <?php echo $style; // @codingStandardsIgnoreLine ?>>

						<div class="slider-thumb">
							<?php books_action( 'slider_thumbnail', 'books-slider' ); ?>
						</div>

						<div class="slider-content">
							<?php
							books_action( 'slider_title' );
							books_action( 'slider_meta_info', $slider_meta_info );
							books_action( 'slider_content', $slider_excerpt );
							echo get_books_readmore( 'More Details', true ); // @codingStandardsIgnoreLine
							?>
						</div>


					</li>

					<?php

				endwhile;

				wp_reset_postdata();

				echo '</ul>';
				?>

			</div><!-- .slider-container -->

		</section>
		<?php
	}

	/**
	 * Get Rating stars
	 */
	public function get_rating() {

		global $product;

		$authorname = $product->get_attribute( 'pa_author-name' );

		$rating_count = $product->get_rating_count();
		$review_count = $product->get_review_count();
		$average      = $product->get_average_rating();
		$total_rating = $average * 10 * 2 . '%';

		?>
		<div class="slider-stars">
			<div class="stars-wrapper">
				<div class="fill-stars" style="width: <?php echo esc_html( $total_rating ); ?>">
					<i class="fa fa-star"></i>
					<i class="fa fa-star"></i>
					<i class="fa fa-star"></i>
					<i class="fa fa-star"></i>
					<i class="fa fa-star"></i>
				</div>
				<div class="empty-stars">
					<i class="fa fa-star-o"></i>
					<i class="fa fa-star-o"></i>
					<i class="fa fa-star-o"></i>
					<i class="fa fa-star-o"></i>
					<i class="fa fa-star-o"></i>
				</div>
			</div>
		</div>
		<?php
	}

	/**
	 * Get Single product gradient to override
	 *
	 * @param String $id for ID.
	 */
	public function get_gradient( $id ) {

		$style    = '';
		$gradient = '';
		$deg      = get_post_meta( $id, 'single_gradient_deg', true );
		$top      = get_post_meta( $id, 'single_gradient_top', true );
		$bottom   = get_post_meta( $id, 'single_gradient_bottom', true );

		if ( $deg && $top && $bottom ) {
			$gradient = join( ', ', [ $deg, $top, $bottom ] );
			$style    = 'style = "background: linear-gradient(' . $gradient . ');"';
		}
		return $style;
	}

}

// Init.
new Home_Slider();
